@@ -1,6 +1,8 @@
+{-# LANGUAGE OverloadedStrings #-}
 module Main where
 
 import Control.Monad
+
 import System.Directory
 
 import System.INotify as INotify
@@ -9,18 +11,18 @@ import Utils
 
 file, file2 :: String
 file = "hello"
-file2 = file ++ "2"
+file2 = "hello2"
 
 write :: String -> IO ()
-write path = do
+write path =
     writeFile (path ++ '/':file) ""
 
 move :: String -> IO ()
-move path = do
+move path =
     renameFile (path ++ '/':file) (path ++ '/':file2)
 
 remove :: String -> IO ()
-remove path = do
+remove path =
     removeFile (path ++ '/':file2)
 
 action :: String -> IO ()
@@ -40,11 +42,11 @@ main =
 
 expected :: Cookie -> [Event]
 expected cookie =
-    [ Created   False file
-    , Opened    False (Just file)
-    , Modified  False (Just file)
-    , Closed    False (Just file) True
-    , MovedOut  False file  cookie
-    , MovedIn   False file2 cookie
-    , Deleted   False file2
+    [ Created   False "hello"
+    , Opened    False (Just "hello")
+    , Modified  False (Just "hello")
+    , Closed    False (Just "hello") True
+    , MovedOut  False "hello"  cookie
+    , MovedIn   False "hello2" cookie
+    , Deleted   False "hello2"
     ]
